@@ -1296,21 +1296,23 @@ class GenericCall(ScaleType):
 
             call_hash = blake2b(self.get_used_bytes(), digest_size=32).digest()
 
-            # Check args format
-            if type(call_obj[1].value_object) is not tuple:
-                call_args_values = (call_obj[1],)
-            else:
-                call_args_values = call_obj[1]
-
             call_args = []
 
-            for idx, call_arg in enumerate(self.call_args):
-                call_args.append({
-                    'name': call_arg.value['name'],
-                    'type': self.convert_type(call_arg.value['typeName']),
-                    'value': call_args_values[idx].value
-                })
-                self.call_args[idx].value_object['value'] = call_args_values[idx]
+            if len(self.call_args) > 0:
+
+                # Check args format
+                if type(call_obj[1].value_object) is not tuple:
+                    call_args_values = (call_obj[1],)
+                else:
+                    call_args_values = call_obj[1]
+
+                for idx, call_arg in enumerate(self.call_args):
+                    call_args.append({
+                        'name': call_arg.value['name'],
+                        'type': self.convert_type(call_arg.value['typeName']),
+                        'value': call_args_values[idx].value
+                    })
+                    self.call_args[idx].value_object['value'] = call_args_values[idx]
 
             self.value_object = {
                 'call_index': f'0x{self.call_index}',
@@ -1671,20 +1673,33 @@ class Map(ScaleType):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-        sub_type_parts = [x.strip() for x in self.sub_type.split(',')]
-        self.map_key = sub_type_parts[0]
-        self.map_value = sub_type_parts[1]
+        self.map_key = None
+        self.map_value = None
+
+        if self.sub_type:
+            sub_type_parts = [x.strip() for x in self.sub_type.split(',')]
+            self.map_key = sub_type_parts[0]
+            self.map_value = sub_type_parts[1]
 
     def process(self):
 
-        element_count = self.process_type('Compact<u32>').value
+        if self.map_key and self.map_value:
 
-        result = []
-        for _ in range(0, element_count):
-            key_value = self.process_type(self.map_key, metadata=self.metadata).value
-            result.append((key_value, self.process_type(self.map_value, metadata=self.metadata).value))
+            element_count = self.process_type('Compact<u32>').value
 
-        return result
+            result = []
+            for _ in range(0, element_count):
+                key_value = self.process_type(self.map_key, metadata=self.metadata).value
+                result.append((key_value, self.process_type(self.map_value, metadata=self.metadata).value))
+
+            return result
+
+        elif self.type_mapping:
+            self.value_object = self.process_type(self.type_mapping[0], metadata=self.metadata)
+            return self.value_object.value
+
+        else:
+            raise ValueError('sub_type or type_mapping should be set to process a Map')
 
     def process_encode(self, value):
 
@@ -1850,34 +1865,17 @@ class GenericMetadataVersioned(Tuple):
     def pallets(self):
         return self.value_object[1].pallets
 
-    def process(self):
-        value = super().process()
-
-        # # Create error index
-        # if self.index >= 12:
-        #     for module in self.metadata.modules:
-        #         if len(module.errors or []) > 0:
-        #             for idx, error in enumerate(module.errors):
-        #                 self.error_index[f'{module.index}-{idx}'] = error
-        # else:
-        #     error_module_index = 0
-        #     for module in self.metadata.modules:
-        #         if len(module.errors or []) > 0:
-        #             for idx, error in enumerate(module.errors):
-        #                 self.error_index[f'{error_module_index}-{idx}'] = error
-        #             error_module_index += 1
-
-        return value
-
     def get_metadata_pallet(self, name: str) -> 'GenericPalletMetadata':
         metadata = self.get_metadata()
         return metadata.get_metadata_pallet(name)
 
     def get_pallet_by_index(self, index: int):
-        try:
-            return self.pallets[index]
-        except IndexError:
-            raise ValueError(f'Pallet for index "{index}" not found')
+
+        for pallet in self.pallets:
+            if pallet.value['index'] == index:
+                return pallet
+
+        raise ValueError(f'Pallet for index "{index}" not found')
 
 
 class GenericStringType(String):
@@ -2474,7 +2472,7 @@ class GenericScaleInfoEvent(Enum):
             'event_index': self.event_index,
             'module_id': self.value_object[0],
             'event_id': self.value_object[1][0],
-            'attributes': self.value_object[1][1].value,
+            'attributes': self.value_object[1][1].value if self.value_object[1][1] else None,
         }
 
 
